#include"windows.h"
#include<stdio.h>
#include<stdlib.h>
#include<Alert.h>
#include<StatusBar.h>

///////////////////////////////////////////
// Class ConfigWindow

ConfigWindow::ConfigWindow(BRect rect) :
		BWindow(rect, CONF_WINDOW_NAME, B_TITLED_WINDOW,
			B_NOT_ZOOMABLE|B_NOT_RESIZABLE|B_NOT_CLOSABLE|B_ASYNCHRONOUS_CONTROLS){
	BRect r;
	
	// Making menubar
	BMenu *menu;
	
	r = Bounds();
	menubar = new BMenuBar(r, "menu_bar");	
	AddChild(menubar);
	
	menu = new BMenu("File");
	menu->AddItem(new BMenuItem("Start", new BMessage(BREAK_START), 'S'));
	menu->AddSeparatorItem();
	menu->AddItem(new BMenuItem("About" B_UTF8_ELLIPSIS, new BMessage(MENU_FILE_ABOUT)));
	menu->AddSeparatorItem();
	menu->AddItem(new BMenuItem("Quit", new BMessage(MENU_FILE_QUIT), 'Q'));
	menubar->AddItem(menu);
	
	// Make Config area
	r.top    = menubar->Bounds().bottom + 1;

	BView *bgview = new BView(r, "bg_view", B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
	bgview->SetViewColor(0xe0, 0xe0, 0xe0);
	
	r = bgview->Bounds();
	r.top = 10;
	r.bottom = r.top + 20;
	r.left   = 10;
	r.right  -= 10;
	titlectr = new BTextControl(r, "title_ctr", "Title:",
		"Processing files", NULL);
	titlectr->SetDivider(50.0);
	bgview->AddChild(titlectr);

	r.top   += 30;
	r.bottom = r.top + 20;
	textctr = new BTextControl(r, "text_ctr", "Label:",
		"Processing:", NULL);
	textctr->SetDivider(50.0);
	bgview->AddChild(textctr);

	r.top += 30;
	r.bottom = r.top + 20;
	timeslider = new BSlider(r, "time_slider", "Time (minutes):", NULL,
		1.0, 60.0, B_TRIANGLE_THUMB);
	timeslider->SetHashMarks(B_HASH_MARKS_TOP);
	timeslider->SetHashMarkCount(7);
	timeslider->SetLimitLabels("1.0", "60.0");
	timeslider->SetValue(15);
	bgview->AddChild(timeslider);
	
	r.top += 60;
	r.bottom = r.top + 20;
	r.right = r.left + 90;
	startbutton = new BButton(r, "start_button", "Start",
		new BMessage(BREAK_START));
	startbutton->MakeDefault(true);
	bgview->AddChild(startbutton);
	
	r.right = Bounds().right - 10;
	r.left = r.right - 90;
	bgview->AddChild(new BButton(r, "cancel_button", "Cancel",
		new BMessage(MENU_FILE_QUIT)));
		
	AddChild(bgview);
}

void ConfigWindow::MessageReceived(BMessage *message){
	switch (message->what){
	case MENU_FILE_ABOUT:
		be_app->PostMessage(B_ABOUT_REQUESTED);
		break;
	case MENU_FILE_QUIT:
		be_app->PostMessage(B_QUIT_REQUESTED);
		break;
	case BREAK_START:
		be_app->PostMessage(BREAK_START);
		break;
	default:
		BWindow::MessageReceived(message);
	}
}

bool ConfigWindow::QuitRequested(void){
	return true;
}

void ConfigWindow::GetValues(char *title, char *label, int32 *time){ 
	strcpy(title, titlectr->Text());
	strcpy(label, textctr->Text());
	*time = timeslider->Value();
}
///////////////////////////////////////////
// Class BreakWindow

BreakWindow::BreakWindow(BRect rect, char *label, int32 time) :
		BWindow(rect, NULL, B_TITLED_WINDOW,
		B_NOT_ZOOMABLE|B_NOT_RESIZABLE|B_ASYNCHRONOUS_CONTROLS){
	curr_time = 0;
	this->title = title;
	this->time = time;
	
	BRect r;
	r = Bounds();
	
	BView *bgview = new BView(r, "break_view", B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
	bgview->SetViewColor(0xe0, 0xe0, 0xe0);
	
	r.top   = 10;
	r.left  = 10;
	r.right = r.right - 10;
	r.bottom = r.bottom / 2;
	statusbar= new BStatusBar(r, "status_bar", label);
	statusbar->SetMaxValue(time*60);
	bgview->AddChild(statusbar);

	r.top = statusbar->Bounds().bottom + 15;
	r.left = r.right - 90;
	BButton *quitbutton = new BButton(r, "quit_button", "Cancel",
		new BMessage(B_QUIT_REQUESTED));
	quitbutton->MakeDefault(true);
	bgview->AddChild(quitbutton);
	
	AddChild(bgview);
}

BreakWindow::~BreakWindow(void){
	be_app->PostMessage(B_QUIT_REQUESTED);
}

bool BreakWindow::QuitRequested(void){
	be_app->SetPulseRate(0);
	BAlert *alert = new BAlert("quit_alert", QUIT_TEXT,
		"Cancel", "Quit", NULL, B_WIDTH_AS_USUAL, B_OFFSET_SPACING, B_STOP_ALERT);
	alert->SetShortcut(0, B_ESCAPE);
	if ((alert->Go()) == 1){
		return true;
	} else {
		be_app->SetPulseRate(1000000);
		return false;
	}
}

void BreakWindow::MessageReceived(BMessage *message){
	switch (message->what){
	case B_QUIT_REQUESTED:
		be_app->PostMessage(B_QUIT_REQUESTED);
		break;
	default:
		BWindow::MessageReceived(message);
		break;
	}
}

void BreakWindow::UpdateBar(int32 delta){
	Lock();
	statusbar->Update(delta);
	Unlock();
}